@@ -1,3 +1,4 @@
+import inspect
 import re
 from typing import Dict, List, Optional, Union
 
@@ -114,7 +115,7 @@ def _get_rich_console() -> Console:
 
 
 def _make_rich_rext(text: str, style: str = "") -> Union[rich.markdown.Markdown, rich.text.Text]:
-    """Take a string and return styled text.
+    """Take a string, remove indentations, and return styled text.
 
     By default, return the text as a Rich Text with the request style.
     If USE_RICH_MARKUP is True, also parse the text for Rich markup strings.
@@ -130,6 +131,8 @@ def _make_rich_rext(text: str, style: str = "") -> Union[rich.markdown.Markdown,
     Returns:
         MarkdownElement or Text: Styled text object
     """
+    # Remove indentations from input text
+    text = inspect.cleandoc(text)
     if USE_MARKDOWN:
         if USE_MARKDOWN_EMOJI:
             text = Emoji.replace(text)
@@ -158,27 +161,33 @@ def _get_help_text(obj: Union[click.Command, click.Group]) -> Union[rich.markdow
     if obj.deprecated:
         yield Text(DEPRECATED_STRING, style=STYLE_DEPRECATED)
 
+    # Fetch and dedent the help text
+    help_text = inspect.cleandoc(obj.help)
+
+    # Trim off anything that comes after \f on its own line
+    help_text = help_text.partition("\f")[0]
+
     # Get the first paragraph
-    first_line = obj.help.split("\n\n")[0]
+    first_line = help_text.split("\n\n")[0]
     # Remove single linebreaks
     if not USE_MARKDOWN and not first_line.startswith("\b"):
         first_line = first_line.replace("\n", " ")
     yield _make_rich_rext(first_line.strip(), STYLE_HELPTEXT_FIRST_LINE)
 
     # Get remaining lines, remove single line breaks and format as dim
-    remaining_lines = obj.help.split("\n\n")[1:]
-    if len(remaining_lines) > 0:
+    remaining_paragraphs = help_text.split("\n\n")[1:]
+    if len(remaining_paragraphs) > 0:
         if not USE_MARKDOWN:
             # Remove single linebreaks
-            remaining_lines = [
+            remaining_paragraphs = [
                 x.replace("\n", " ").strip() if not x.startswith("\b") else "{}\n".format(x.strip("\b\n"))
-                for x in remaining_lines
+                for x in remaining_paragraphs
             ]
             # Join back together
-            remaining_lines = "\n".join(remaining_lines)
+            remaining_lines = "\n".join(remaining_paragraphs)
         else:
-            # Join with single linebreaks if markdown
-            remaining_lines = "\n\n".join(remaining_lines)
+            # Join with double linebreaks if markdown
+            remaining_lines = "\n\n".join(remaining_paragraphs)
 
         yield _make_rich_rext(remaining_lines, STYLE_HELPTEXT)
 
@@ -325,6 +334,14 @@ def rich_format_help(
         # See https://click.palletsprojects.com/en/8.0.x/documentation/#documenting-arguments
         if type(param) is click.core.Argument and not SHOW_ARGUMENTS:
             continue
+        # Lazy-load typer in case it's not being used
+        try:
+            from typer.core import TyperArgument
+
+            if type(param) is TyperArgument and not SHOW_ARGUMENTS:
+                continue
+        except ImportError:
+            pass
 
         # Skip if option is hidden
         if getattr(param, "hidden", False):
@@ -475,6 +492,8 @@ def rich_format_help(
                 if command not in obj.list_commands(ctx):
                     continue
                 cmd = obj.get_command(ctx, command)
+                if cmd.hidden:
+                    continue
                 # Use the truncated short text as with vanilla text if requested
                 if USE_CLICK_SHORT_HELP:
                     helptext = cmd.get_short_help_str()
